#!/bin/dash - 
#===============================================================================
#
#          FILE: build_all.sh
# 
#         USAGE: ./build_all.sh 
# 
#   DESCRIPTION: combines all policies
# 
#       OPTIONS: ---
#  REQUIREMENTS: xsltproc
#          BUGS: ---
#         NOTES: ---
#        AUTHOR: Andreas Romeyke, 
#  ORGANIZATION: SLUB
#       CREATED: 08.09.2020 09:19
#      REVISION:  ---
#===============================================================================

set -o nounset                              # Treat unset variables as an error

RED="\\e[31m"
WHITE="\\e[0m"
ERROR="${RED}[ERROR]\t${WHITE}"
INFO="[INFO]\t"

BUILD="./build"
REQUIREMENTS="mktemp xsltproc"              # list external required binaries here (space separated)

for REQUIREMENT in ${REQUIREMENTS}; do
  command -v "${REQUIREMENT}" >/dev/null 2>&1 || { echo >&2 "${ERROR}${REQUIREMENT} required but not installed. Aborting."; exit 1; }
done

if [ -d ${BUILD} ]; then
  echo "${INFO}BUILD-dir '${BUILD}' already exists. It will be removed and recreated for a fresh build."
  rm -rf "${BUILD}" || { echo >&2 "${ERROR}Could not remove pre-existing build directory at '${BUILD}'. Aborting."; exit 1; }
fi

TEMP_FILE="$(mktemp)"
COMBINED_FILE="${BUILD}/SLUB_mediaconch_policy_all.xml"
mkdir -p "${BUILD}" || { echo >&2 "${ERROR}Could not create build directory at '${BUILD}'. Aborting."; exit 1; }
echo '<?xml version="1.0" encoding="UTF-8"?>' > "${TEMP_FILE}"
echo '<policy />' >> "${TEMP_FILE}"
xsltproc "SLUB_mediaconch_policy_all.xsl" "${TEMP_FILE}" > "${COMBINED_FILE}"
rm -f "${TEMP_FILE}"
ls -lh "${COMBINED_FILE}"
echo "${INFO}finished."

